# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkarms.endpoint import endpoint_data

class ImportAppAlertRulesRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'ARMS', '2019-08-08', 'ImportAppAlertRules','arms')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_IsAutoStart(self): # Boolean
		return self.get_query_params().get('IsAutoStart')

	def set_IsAutoStart(self, IsAutoStart):  # Boolean
		self.add_query_param('IsAutoStart', IsAutoStart)
	def get_ContactGroupIds(self): # String
		return self.get_query_params().get('ContactGroupIds')

	def set_ContactGroupIds(self, ContactGroupIds):  # String
		self.add_query_param('ContactGroupIds', ContactGroupIds)
	def get_Pids(self): # String
		return self.get_query_params().get('Pids')

	def set_Pids(self, Pids):  # String
		self.add_query_param('Pids', Pids)
	def get_TemplageAlertConfig(self): # String
		return self.get_query_params().get('TemplageAlertConfig')

	def set_TemplageAlertConfig(self, TemplageAlertConfig):  # String
		self.add_query_param('TemplageAlertConfig', TemplageAlertConfig)
	def get_TemplateAlertId(self): # String
		return self.get_query_params().get('TemplateAlertId')

	def set_TemplateAlertId(self, TemplateAlertId):  # String
		self.add_query_param('TemplateAlertId', TemplateAlertId)
